===========================
GLM: Second level analysis
===========================

These are examples focused on showcasing second level models functionality and group level analysis.

See :ref:`glm` for more details.
